@@ -19,14 +19,15 @@ extern void F77_NAME(loglikcontilmsinr)(int *, int *, int *, int *, int *, doubl
 extern void F77_NAME(loglikcontilm)(int *, int *, int *, int *, int *, double *, double *, double *,
                                     double *, double *, double *, double *, double *, double *, double *, double *,
                                     double *, double *, double *);
-extern void F77_NAME(mcmcsir)(int *, int *, int *, int *, int *, int *, int *, double *,
-                              double *, double *, int *, int *, int *, int *, int *, int *,
-                              int *, double *, double *, double *, double *, double *, double *, double *,
-                              double *, double *, double *, double *, double *, double *, double *, double *,
-                              double *, double *, double *, double *, double *, double *, double *, double *,
-                              double *, double *, double *, double *, double *, double *, double *, double *,
-                              double *, double *, double *, double *, double *, double *, double *, double *,
-                              double *);
+
+extern void F77_NAME(mcmcsir)(int *, int *, int *, int *, int *, int *, int *, int *, double *,
+                               double *, double *, int *, int *, int *, int *, int *, int *,
+                               int *, double *, double *, double *, double *, double *, double *, double *,
+                               double *, double *, double *, double *, double *, double *, double *, double *,
+                               double *, double *, double *, double *, double *, double *, double *, double *,
+                               double *, double *, double *, double *, double *, double *, double *, double *,
+                               double *, double *, double *, double *, double *, double *, double *, double *);
+
 extern void F77_NAME(mcmcsinr)(int *, int *, int *, int *, int *, int *, int *, int *, double *,
                                double *, double *, int *, int *, int *, int *, int *, int *,
                                int *, int *, double *, double *, double *, double *, double *,
@@ -36,6 +37,22 @@ extern void F77_NAME(mcmcsinr)(int *, int *, int *, int *, int *, int *, int *,
                                double *, double *, double *, double *, double *, double *, double *, double *,
                                double *, double *, double *, double *, double *, double *, double *, double * );
 
+extern void F77_NAME(mcmcsinr2)(int *, int *, int *, int *, int *, int *, int *, int *, double *,
+                               double *, double *, int *, int *, int *, int *, int *, int *,
+                               int *, int *, double *, double *, double *, double *, double *,
+                               double *, double *, double *, double *, double *, double *, double *, double *,
+                               double *, double *, double *, double *, double *, double *, double *, double *,
+                               double *, double *, double *, double *, double *, double *, double *, double *,
+                               double *, double *, double *, double *, double *, double *, double *, double *,
+                               double *, double *, double *, double *, double *, double *, double *, double * );
+
+extern void F77_NAME(mcmcsir2)(int *, int *, int *, int *, int *, int *, int *, int *, double *,
+                              double *, double *, int *, int *, int *, int *, int *, int *,
+                              int *, double *, double *, double *, double *, double *, double *, double *,
+                              double *, double *, double *, double *, double *, double *, double *, double *,
+                              double *, double *, double *, double *, double *, double *, double *, double *,
+                              double *, double *, double *, double *, double *, double *, double *, double *,
+                              double *, double *, double *, double *, double *, double *, double *, double *);
 
 void F77_SUB(infinity_value)(double *infval){
     *infval = INFINITY;
@@ -48,6 +65,8 @@ static const R_FortranMethodDef FortranEntries[] = {
     {"loglikcontilm",       (DL_FUNC) &F77_NAME(loglikcontilm),         19},
     {"mcmcsir",             (DL_FUNC) &F77_NAME(mcmcsir),               57},
     {"mcmcsinr",            (DL_FUNC) &F77_NAME(mcmcsinr),              64},
+    {"mcmcsinr2",           (DL_FUNC) &F77_NAME(mcmcsinr),              64},
+    {"mcmcsir2",            (DL_FUNC) &F77_NAME(mcmcsir2),              57},
     {NULL, NULL, 0}
 };
 
